require 'roxml'

module Salesforce
	module Types
		# A generic FieldPermissions class that can be extended for specific
		# metadata objects, e.g. PermissionSetFieldPermissions.
		#
		# @author Ben Burwell
		class FieldPermissions
			include ROXML

			xml_accessor :editable
			xml_accessor :field
			xml_accessor :readable

			# A Unix flag style representation of the permissions, suitable for
			# printing in a table
			#
			# @return [String] the granted permissions
			def to_flag_style
				permissions = ''

				if @editable == 'true'
					permissions += 'editable '
				else
					permissions += '         '
				end

				if @readable == 'true'
					permissions += 'readable'
				else
					permissions += '        '
				end

				permissions
			end
		end

		class PermissionSetFieldPermissions < FieldPermissions; end
	end
end
