require 'roxml'

module Salesforce
	module Types
		# A generic ObjectPermissions class that can be extended for specific
		# metadata objects, e.g. ProfileObjectPermissions.
		#
		# @author Ben Burwell
		class ObjectPermissions
			include ROXML

			xml_accessor :allowCreate
			xml_accessor :allowDelete
			xml_accessor :allowEdit
			xml_accessor :allowRead
			xml_accessor :modifyAllRecords
			xml_accessor :object
			xml_accessor :viewAllRecords

			# Get an array of granted permissions
			#
			# @return [Array] an array of strings, like ['allowCreate', 'allowRead']
			def get_permissions
				permissions = []
				permissions.push 'allowCreate' if @allowCreate == 'true'
				permissions.push 'allowDelete' if @allowDelete == 'true'
				permissions.push 'allowEdit' if @allowEdit == 'true'
				permissions.push 'allowRead' if @allowRead == 'true'
				permissions.push 'modifyAllRecords' if @modifyAllRecords == 'true'
				permissions.push 'viewAllRecords' if @viewAllRecords == 'true'
				permissions
			end

			# A Unix flag style representation of the permissions, suitable for
			# printing in a table
			#
			# @return [String] the granted permissions
			def to_flag_style
				permissions = ''

				if @allowCreate == 'true'
					permissions += 'allowCreate '
				else
					permissions += '            '
				end

				if @allowDelete == 'true'
					permissions += 'allowDelete '
				else
					permissions += '            '
				end

				if @allowEdit == 'true'
					permissions += 'allowEdit '
				else
					permissions += '          '
				end

				if @allowRead == 'true'
					permissions += 'allowRead '
				else
					permissions += '          '
				end

				if @modifyAllRecords == 'true'
					permissions += 'modifyAllRecords '
				else
					permissions += '                 '
				end

				if @viewAllRecords == 'true'
					permissions += 'viewAllRecords'
				else
					permissions += '              '
				end

				permissions
			end

		end

		# See https://developer.salesforce.com/docs/atlas.en-us.api_meta.meta/api_meta/meta_profile.htm#profileobjectpermissions_title
		class ProfileObjectPermissions < ObjectPermissions; end

		class PermissionSetObjectPermissions < ObjectPermissions; end
	end
end
